==> kadu-0.12.2.tar.bz2: kadu-0.12.2/plugins/sms/translations/sms_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Pseudonyme SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Application</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Utiliser l&apos;application SMS intégrée</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Application SMS personnalisée</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Utiliser une chaîne SMS personnalisée</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Chaîne SMS personnalisée</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Passerelles</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Envoyer un SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Passerelle SMS T-Mobile.pl</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorisé</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Id utilisateur (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Cochez cette case si votre application sms ne comprend pas les arguments : le nombre: number &amp;message&amp;
Les arguments doivent être séparés par des espaces. L&apos;argument %k est converti en nombre, %m en message</translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation>Proxy SMS pour l&apos;application intégrée</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Envoyez SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Envoyez SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Destinataire</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Sélectionner automatiquement</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Fournisseur GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signature</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Sauvgarder le SMS en historique</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Envoyer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>L&apos;application SMS n&apos;était spécifiée. Visiter la section de configuration</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation> - Sélectionner le destinataire - </translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Envoi du SMS...</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Impossible de reproduire le processus fils. Vérifiez si le programme est fonctionnel</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Ce processus s&apos;est terminé anormalement. Le SMS pourrait ne pas avoir été envoyé</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>Envoyer un SMS</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Sélection automatique de la passerelle indisponible. Veuillez sélectionner une passerelle SMS manuellement.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation>La signature ne peut pas être vide.</translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation>Détection de la passerelle...</translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation>Passerelle détectée : %1.</translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Envoi du SMS...</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>Envoyer un SMS</translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Received token value.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_1.1.orig.tar.bz2: kadu-1.1/plugins/sms/translations/sms_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Application</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Utiliser l&apos;application SMS intégrée</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Application SMS personnalisée</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Passerelles</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Envoyer un SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Passerelle SMS T-Mobile.pl</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorisé</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Id utilisateur (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Cochez cette case si votre application sms ne comprend pas les arguments : le nombre: number &amp;message&amp;
Les arguments doivent être séparés par des espaces. L&apos;argument %k est converti en nombre, %m en message</translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation>Proxy SMS pour l&apos;application intégrée</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your nick for SMS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use application custom arguments</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS custom arguments</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Envoyez SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Envoyez SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Destinataire</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Sélectionner automatiquement</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Fournisseur GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signature</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Sauvgarder le SMS en historique</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Envoyer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>L&apos;application SMS n&apos;était spécifiée. Visiter la section de configuration</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation> - Sélectionner le destinataire - </translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Envoi du SMS...</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Impossible de reproduire le processus fils. Vérifiez si le programme est fonctionnel</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Ce processus s&apos;est terminé anormalement. Le SMS pourrait ne pas avoir été envoyé</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>Envoyer un SMS</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Sélection automatique de la passerelle indisponible. Veuillez sélectionner une passerelle SMS manuellement.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation>La signature ne peut pas être vide.</translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation>Détection de la passerelle...</translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation>Passerelle détectée : %1.</translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Envoi du SMS...</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>Envoyer un SMS</translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Received token value.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
